(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define('element/locale/tk', ['module', 'exports'], factory);
  } else if (typeof exports !== "undefined") {
    factory(module, exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod, mod.exports);
    global.ELEMENT.lang = global.ELEMENT.lang || {}; 
    global.ELEMENT.lang.tk = mod.exports;
  }
})(this, function (module, exports) {
  'use strict';

  exports.__esModule = true;
  exports.default = {
    el: {
      colorpicker: {
        confirm: 'OK',
        clear: 'Arassala'
      },
      datepicker: {
        now: 'Şuwagt',
        today: 'Şügün',
        cancel: 'Bes et',
        clear: 'Arassala',
        confirm: 'OK',
        selectDate: 'Güni saýlaň',
        selectTime: 'Wagty saýlaň',
        startDate: 'Başlaýan güni',
        startTime: 'Başlaýan wagty',
        endDate: 'Gutarýan güni',
        endTime: 'Gutarýan wagty',
        prevYear: 'Previous Year', // to be translated
        nextYear: 'Next Year', // to be translated
        prevMonth: 'Previous Month', // to be translated
        nextMonth: 'Next Month', // to be translated
        year: '',
        month1: 'Ýan',
        month2: 'Few',
        month3: 'Mar',
        month4: 'Apr',
        month5: 'Maý',
        month6: 'Iýn',
        month7: 'Iýl',
        month8: 'Awg',
        month9: 'Sen',
        month10: 'Okt',
        month11: 'Noý',
        month12: 'Dek',
        // week: 'week',
        weeks: {
          sun: 'Ýek',
          mon: 'Duş',
          tue: 'Siş',
          wed: 'Çar',
          thu: 'Pen',
          fri: 'Ann',
          sat: 'Şen'
        },
        months: {
          jan: 'Ýan',
          feb: 'Few',
          mar: 'Mar',
          apr: 'Apr',
          may: 'Maý',
          jun: 'Iýn',
          jul: 'Iýl',
          aug: 'Awg',
          sep: 'Sep',
          oct: 'Okt',
          nov: 'Noý',
          dec: 'Dek'
        }
      },
      select: {
        loading: 'Indirilýär',
        noMatch: 'Hiçzat tapylmady',
        noData: 'Hiçzat ýok',
        placeholder: 'Saýla'
      },
      cascader: {
        noMatch: 'Hiçzat tapylmady',
        loading: 'Indirilýär',
        placeholder: 'Saýlaň',
        noData: 'Hiçzat ýok'
      },
      pagination: {
        goto: 'Git',
        pagesize: '/sahypa',
        total: 'Umumy {total}',
        pageClassifier: ''
      },
      messagebox: {
        title: 'Hat',
        confirm: 'OK',
        cancel: 'Bes et',
        error: 'Ýalňyş girizme'
      },
      upload: {
        deleteTip: 'Pozmak üçin "poz" düwmä basyň',
        delete: 'Poz',
        preview: 'Gör',
        continue: 'Dowam et'
      },
      table: {
        emptyText: 'Maglumat ýok',
        confirmFilter: 'Tassykla',
        resetFilter: 'Arassala',
        clearFilter: 'Hemmesi',
        sumText: 'Jemi'
      },
      tree: {
        emptyText: 'Maglumat ýok'
      },
      transfer: {
        noMatch: 'Hiçzat tapylmady',
        noData: 'Hiçzat ýok',
        titles: ['Sanaw 1', 'Sanaw 2'],
        filterPlaceholder: 'Gözleg sözlerini giriziň',
        noCheckedFormat: '{total} sany',
        hasCheckedFormat: '{checked}/{total} saýlanan'
      },
      image: {
        error: 'FAILED' // to be translated
      },
      pageHeader: {
        title: 'Back' // to be translated
      },
      popconfirm: {
        confirmButtonText: 'Yes', // to be translated
        cancelButtonText: 'No' // to be translated
      }
    }
  };
  module.exports = exports['default'];
});