@import "base";

@primary: #2096c8 !important;
@color: white;

@menu-color: #8aa4af !important;
@menu-background: #2b3539 !important;

@menu-color-hover: #FFF;
@menu-background-hover: #1f272b;

@menu-title-color: #FFF;
@menu-title-background-color: #212c32;

@menu-title-color-hover: #FFF;
@menu-title-background-color-hover: #1f272b;


@navbar-color: #fff;
@navbar-background: #3c8dbc;

.logo-wrap {
  color: @navbar-color !important;
  background-color: @navbar-background !important;
}

.menu .el-menu .is-active {
  color: #FFF !important;
}

.navbar {

  .el-button:focus, .el-button:hover {
    color: rgba(@color, 0.7) !important;
  }
}