
.el-tabs--border-card > .el-tabs__header .el-tabs__item.is-active {
  color: @primary;
  border-bottom: @primary 2px solid !important;
}

.el-button--text {
  color: @primary;
}

.el-button--primary:focus, .el-button--primary:hover {
  color: @color;
  border-color: rgba(@primary, 0.9);
  background-color: rgba(@primary, 0.8);
}

.el-dropdown-menu__item:focus, .el-dropdown-menu__item:not(.is-disabled):hover {
  background-color: rgba(@primary, 0.2);
  color: @primary;
}

.el-select-dropdown__item.selected {
  color: @primary !important;
}

input[type=text]:focus, input[type=password]:focus, input[type=email]:focus, input[type=url]:focus, input[type=number]:focus, input[type=tel]:focus, textarea:focus, select:focus, .vTextField:focus {
  border-color: @primary;
}

.el-button--primary {
  background-color: @primary;
  border-color: @primary;
}

tbody a:link, tbody a:visited {
  color: @primary;
}

tbody tr:hover td, tbody tr:hover th {
  background-color: rgba(@primary, 0.2);
}

a:link, a:visited {
  color: @primary;
}

.results {
  color: inherit !important;
}

.el-select-dropdown__item.hover, .el-select-dropdown__item:hover {
  background-color: rgba(@primary, 0.2);
}

.el-date-table td.today span {
  color: @primary;
}

.el-date-table td.available:hover {
  color: @primary;
}

.el-picker-panel__icon-btn:hover {
  color: rgba(@primary, 0.8);
}

.el-range-editor.is-active, .el-range-editor.is-active:hover {
  border-color: @primary;
}

.el-date-table td.end-date span, .el-date-table td.start-date span {
  background-color: @primary;
}

.el-date-table td.in-range div, .el-date-table td.in-range div:hover, .el-date-table.is-week-mode .el-date-table__row.current div, .el-date-table.is-week-mode .el-date-table__row:hover div {
  background-color: rgba(@primary, 0.2);
}

.el-time-panel__btn.confirm {
  color: @primary;
}

.el-pagination.is-background .el-pager li:not(.disabled).active {
  color: @color;
  background-color: @primary;
}

.el-pagination.is-background .el-pager li:not(.disabled):hover {
  color: @primary;
}

.el-tabs--border-card > .el-tabs__header .el-tabs__item:not(.is-disabled):hover {
  color: @primary;
  //border-bottom: @primary 2px solid;
}

.navbar {
  background-color: @navbar-background;

  .el-button:focus, .el-button:hover {
    color: @primary;
  }

  .el-button, .el-breadcrumb__item:last-child .el-breadcrumb__inner, .el-breadcrumb__item:last-child .el-breadcrumb__inner a, .el-breadcrumb__item:last-child .el-breadcrumb__inner a:hover, .el-breadcrumb__item:last-child .el-breadcrumb__inner:hover {
    color: @navbar-color;
  }

  .el-breadcrumb__inner, .el-breadcrumb__separator {
    color: @navbar-color;
  }
}

.logo-wrap {
  color: @menu-color;
}

.menu {
  background-color: @menu-background;

  .el-menu-item {
    color: @menu-color;
  }

  .el-menu-item:hover {
    color: @menu-color-hover;
  }

  .el-menu .is-active {
    color: @primary;
  }

  .el-menu-item-group, .el-menu-item {
    background-color: @menu-background;
  }

  .el-menu-item:hover {
    background-color: @menu-background-hover !important;
    color: @menu-color-hover !important;
  }

  .el-menu-item i {
    color: inherit;
  }

  .el-submenu__title {
    .far, .fa, .fab, .fas {
      color: inherit;
    }
  }

  .el-submenu__title i {
    color: @menu-title-color !important;
  }

  .el-submenu__title {
    color: @menu-title-color !important;
    background-color: @menu-title-background-color !important;
  }

  .el-submenu__title:hover, .is-opened .el-submenu__title {
    color: @menu-title-color-hover !important;
    background-color: @menu-title-background-color-hover !important;
  }
}

.quick-card a:hover {
  color: rgba(@primary, 0.8);
}

.module h2, .module caption, .inline-group h2, .selector-chosen h2 {
  background: @navbar-color !important;
  color: @menu-title-color-hover !important;
}

#changelist .actions {
  min-height: 38px;
}

.colM {
  overflow: auto;
}