#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2022/6/15 10:13 上午
# @Author  : Jieay
# @File    : sub_urls
# 子服务路由 url 注册
from django.conf.urls import url, include, re_path


urlpatterns = []