#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020-05-01 16:43
# @Author  : Jieay
# @File    : __init__.py.py
from app.models.common.fake_model import *
from app.models.user.members import *